==> kubernetes-model-core-5.8.0-sources.jar: io/fabric8/kubernetes/api/model/ConfigMapProjectionFluent.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface ConfigMapProjectionFluent<A extends io.fabric8.kubernetes.api.model.ConfigMapProjectionFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public A addToItems(java.lang.Integer index,io.fabric8.kubernetes.api.model.KeyToPath item);
  public A setToItems(java.lang.Integer index,io.fabric8.kubernetes.api.model.KeyToPath item);
  public A addToItems(io.fabric8.kubernetes.api.model.KeyToPath... items);
  public A addAllToItems(java.util.Collection<io.fabric8.kubernetes.api.model.KeyToPath> items);
  public A removeFromItems(io.fabric8.kubernetes.api.model.KeyToPath... items);
  public A removeAllFromItems(java.util.Collection<io.fabric8.kubernetes.api.model.KeyToPath> items);
  public A removeMatchingFromItems(java.util.function.Predicate<io.fabric8.kubernetes.api.model.KeyToPathBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.kubernetes.api.model.KeyToPath> getItems();
  public java.util.List<io.fabric8.kubernetes.api.model.KeyToPath> buildItems();
  public io.fabric8.kubernetes.api.model.KeyToPath buildItem(java.lang.Integer index);
  public io.fabric8.kubernetes.api.model.KeyToPath buildFirstItem();
  public io.fabric8.kubernetes.api.model.KeyToPath buildLastItem();
  public io.fabric8.kubernetes.api.model.KeyToPath buildMatchingItem(java.util.function.Predicate<io.fabric8.kubernetes.api.model.KeyToPathBuilder> predicate);
  public java.lang.Boolean hasMatchingItem(java.util.function.Predicate<io.fabric8.kubernetes.api.model.KeyToPathBuilder> predicate);
  public A withItems(java.util.List<io.fabric8.kubernetes.api.model.KeyToPath> items);
  public A withItems(io.fabric8.kubernetes.api.model.KeyToPath... items);
  public java.lang.Boolean hasItems();
  public A addNewItem(java.lang.String key,java.lang.Integer mode,java.lang.String path);
  public io.fabric8.kubernetes.api.model.ConfigMapProjectionFluent.ItemsNested<A> addNewItem();
  public io.fabric8.kubernetes.api.model.ConfigMapProjectionFluent.ItemsNested<A> addNewItemLike(io.fabric8.kubernetes.api.model.KeyToPath item);
  public io.fabric8.kubernetes.api.model.ConfigMapProjectionFluent.ItemsNested<A> setNewItemLike(java.lang.Integer index,io.fabric8.kubernetes.api.model.KeyToPath item);
  public io.fabric8.kubernetes.api.model.ConfigMapProjectionFluent.ItemsNested<A> editItem(java.lang.Integer index);
  public io.fabric8.kubernetes.api.model.ConfigMapProjectionFluent.ItemsNested<A> editFirstItem();
  public io.fabric8.kubernetes.api.model.ConfigMapProjectionFluent.ItemsNested<A> editLastItem();
  public io.fabric8.kubernetes.api.model.ConfigMapProjectionFluent.ItemsNested<A> editMatchingItem(java.util.function.Predicate<io.fabric8.kubernetes.api.model.KeyToPathBuilder> predicate);
  public java.lang.String getName();
  public A withName(java.lang.String name);
  public java.lang.Boolean hasName();
  
  /**
   * Method is deprecated. use withName instead.
   */
  @java.lang.Deprecated
  public A withNewName(java.lang.String arg0);
  public java.lang.Boolean getOptional();
  public A withOptional(java.lang.Boolean optional);
  public java.lang.Boolean hasOptional();
  public interface ItemsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.KeyToPathFluent<io.fabric8.kubernetes.api.model.ConfigMapProjectionFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}

==> kubernetes-model-core-5.10.2-sources.jar: io/fabric8/kubernetes/api/model/ConfigMapProjectionFluent.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface ConfigMapProjectionFluent<A extends io.fabric8.kubernetes.api.model.ConfigMapProjectionFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public A addToItems(java.lang.Integer index,io.fabric8.kubernetes.api.model.KeyToPath item);
  public A setToItems(java.lang.Integer index,io.fabric8.kubernetes.api.model.KeyToPath item);
  public A addToItems(io.fabric8.kubernetes.api.model.KeyToPath... items);
  public A addAllToItems(java.util.Collection<io.fabric8.kubernetes.api.model.KeyToPath> items);
  public A removeFromItems(io.fabric8.kubernetes.api.model.KeyToPath... items);
  public A removeAllFromItems(java.util.Collection<io.fabric8.kubernetes.api.model.KeyToPath> items);
  public A removeMatchingFromItems(java.util.function.Predicate<io.fabric8.kubernetes.api.model.KeyToPathBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.kubernetes.api.model.KeyToPath> getItems();
  public java.util.List<io.fabric8.kubernetes.api.model.KeyToPath> buildItems();
  public io.fabric8.kubernetes.api.model.KeyToPath buildItem(java.lang.Integer index);
  public io.fabric8.kubernetes.api.model.KeyToPath buildFirstItem();
  public io.fabric8.kubernetes.api.model.KeyToPath buildLastItem();
  public io.fabric8.kubernetes.api.model.KeyToPath buildMatchingItem(java.util.function.Predicate<io.fabric8.kubernetes.api.model.KeyToPathBuilder> predicate);
  public java.lang.Boolean hasMatchingItem(java.util.function.Predicate<io.fabric8.kubernetes.api.model.KeyToPathBuilder> predicate);
  public A withItems(java.util.List<io.fabric8.kubernetes.api.model.KeyToPath> items);
  public A withItems(io.fabric8.kubernetes.api.model.KeyToPath... items);
  public java.lang.Boolean hasItems();
  public A addNewItem(java.lang.String key,java.lang.Integer mode,java.lang.String path);
  public io.fabric8.kubernetes.api.model.ConfigMapProjectionFluent.ItemsNested<A> addNewItem();
  public io.fabric8.kubernetes.api.model.ConfigMapProjectionFluent.ItemsNested<A> addNewItemLike(io.fabric8.kubernetes.api.model.KeyToPath item);
  public io.fabric8.kubernetes.api.model.ConfigMapProjectionFluent.ItemsNested<A> setNewItemLike(java.lang.Integer index,io.fabric8.kubernetes.api.model.KeyToPath item);
  public io.fabric8.kubernetes.api.model.ConfigMapProjectionFluent.ItemsNested<A> editItem(java.lang.Integer index);
  public io.fabric8.kubernetes.api.model.ConfigMapProjectionFluent.ItemsNested<A> editFirstItem();
  public io.fabric8.kubernetes.api.model.ConfigMapProjectionFluent.ItemsNested<A> editLastItem();
  public io.fabric8.kubernetes.api.model.ConfigMapProjectionFluent.ItemsNested<A> editMatchingItem(java.util.function.Predicate<io.fabric8.kubernetes.api.model.KeyToPathBuilder> predicate);
  public java.lang.String getName();
  public A withName(java.lang.String name);
  public java.lang.Boolean hasName();
  
  /**
   * Method is deprecated. use withName instead.
   */
  @java.lang.Deprecated
  public A withNewName(java.lang.String arg0);
  public java.lang.Boolean getOptional();
  public A withOptional(java.lang.Boolean optional);
  public java.lang.Boolean hasOptional();
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value);
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public A removeFromAdditionalProperties(java.lang.String key);
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties);
  public java.lang.Boolean hasAdditionalProperties();
  public interface ItemsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.KeyToPathFluent<io.fabric8.kubernetes.api.model.ConfigMapProjectionFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}
